@@ -4,30 +4,31 @@ from sqlalchemy.exc import OperationalError
 from .seed import Seed
 from ..base import DatabaseSessionManager
 from ...dependency import IScoped
-from ...dependency.container import DependencyContainer
+from ...dependency.provider import ServiceProvider
 from ...logging.loggers.sql import SqlLogger
 
 
 class SeedRunner(IScoped):
     @inject
     def __init__(self,
-                 database_session_manager: DatabaseSessionManager,
-                 logger: SqlLogger
-
+                 logger: SqlLogger,
+                 service_provider: ServiceProvider,
                  ):
+        self.service_provider = service_provider
         self.logger = logger
-        self.database_session_manager = database_session_manager
 
     def run(self):
         try:
-            self.database_session_manager.engine.connect()
-            for seedClass in Seed.__subclasses__():
+            # trying to connect database first
+            database_session_manager = self.service_provider.get(DatabaseSessionManager)
+            database_session_manager.connect()
+            for seed_class in Seed.__subclasses__():
                 try:
-                    instance = DependencyContainer.Instance.get(seedClass)
+                    instance = self.service_provider.get(seed_class)
                     instance.seed()
                 except Exception as ex:
                     self.logger.exception(ex, "Class instance not found on container.")
-                    instance = seedClass()
+                    instance = seed_class()
                     instance.seed()
 
         except OperationalError as opex:
@@ -35,4 +36,4 @@ class SeedRunner(IScoped):
         except Exception as ex:
             self.logger.exception(ex, "Seeds getting error.")
         finally:
-            self.database_session_manager.close()
+            self.service_provider.get(DatabaseSessionManager).close()
