@@ -73,8 +73,4 @@ class ImpalaConnector(BigDataConnector):
             except Exception as error:
                 self.connection.rollback()
                 self.cursor.close()
-                raise
-
-    def get_target_query_indexer(self):
-        indexer = '?'
-        return indexer
\ No newline at end of file
+                raise
\ No newline at end of file
