@@ -19,7 +19,7 @@ class OperationExecutionInitializerFactory(IScoped):
         if subclasses is not None and len(subclasses) > 0:
             if len(subclasses) > 1:
                 initializer_classes = [subclass for subclass in subclasses if
-                                       not isinstance(subclass, DefaultOperationExecutionInitializer)]
+                                       subclass != DefaultOperationExecutionInitializer]
                 initializer_class = initializer_classes[0]
             else:
                 initializer_class = subclasses[0]
