@@ -26,9 +26,9 @@ class MessageBroker:
         self.close()
 
     def close(self):
-        if self.worker.is_alive() and not self.worker.stopped():
+        if self.worker is not None and self.worker.is_alive() and not self.worker.stopped():
             self.worker.stop()
-        if self.listener.is_alive() and not self.listener.stopped():
+        if self.listener is not None and self.listener.is_alive() and not self.listener.stopped():
             self.listener.stop()
         if self.manager is not None:
             self.manager.shutdown()
